@@ -50,10 +50,8 @@ def main():
             'debug': logging.DEBUG,
         }[args.log_level],
         format='[%(asctime)s] %(name)s %(levelname)s: %(message)s',
-        force=True,
+        # force=True,
     )
     logging.Formatter.converter = lambda *args: datetime.now(
         tz=timezone('UTC')).timetuple()
-    # if len(args.constituents) == 0:
-    #     args.constituents = ['all']
     BestTrackRunCommand(args).run()
